"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/library/actions/CartActions.ts
var CartActions_exports = {};
__export(CartActions_exports, {
  getCartActions: () => getCartActions
});
module.exports = __toCommonJS(CartActions_exports);
var import_frontend_sdk = require("@commercetools/frontend-sdk");
var getCartActions = (sdk) => {
  return {
    getCart: async (options = {}) => {
      const response = await sdk.callAction({
        actionName: "cart/getCart",
        serverOptions: options.serverOptions
      });
      if (!response.isError) {
        sdk.trigger(
          new import_frontend_sdk.Event({
            eventName: "cartFetched",
            data: {
              cart: response
            }
          })
        );
      }
      return response;
    },
    addItem: async (payload, options = {}) => {
      const response = await sdk.callAction({
        actionName: "cart/addToCart",
        payload,
        serverOptions: options.serverOptions
      });
      if (!response.isError) {
        sdk.trigger(
          new import_frontend_sdk.Event({
            eventName: "productAddedToCart",
            data: {
              product: payload.variant,
              quantity: payload.variant.count
            }
          })
        );
      }
      return response;
    },
    removeItem: async (payload, options = {}) => {
      const response = await sdk.callAction({
        actionName: "cart/removeLineItem",
        payload,
        serverOptions: options.serverOptions
      });
      if (!response.isError) {
        sdk.trigger(
          new import_frontend_sdk.Event({
            eventName: "productRemovedFromCart",
            data: {
              product: payload.lineItem,
              quantity: 1
            }
          })
        );
      }
      return response;
    },
    updateItem: async (payload, options = {}) => {
      const response = await sdk.callAction({
        actionName: "cart/updateLineItem",
        payload,
        serverOptions: options.serverOptions
      });
      if (!response.isError) {
        sdk.trigger(
          new import_frontend_sdk.Event({
            eventName: "productUpdatedInCart",
            data: {
              product: {
                id: payload.lineItem.id
              },
              newQuantity: payload.lineItem.count
            }
          })
        );
      }
      return response;
    },
    updateCart: async (payload, options = {}) => {
      const response = await sdk.callAction({
        actionName: "cart/updateCart",
        payload,
        serverOptions: options.serverOptions
      });
      if (!response.isError) {
        sdk.trigger(
          new import_frontend_sdk.Event({
            eventName: "cartUpdated",
            data: payload
          })
        );
      }
      return response;
    },
    getShippingMethods: async (payload, options = {}) => {
      const response = await sdk.callAction({
        actionName: "cart/getShippingMethods",
        query: payload?.query ?? void 0,
        serverOptions: options.serverOptions
      });
      if (!response.isError) {
        sdk.trigger(
          new import_frontend_sdk.Event({
            eventName: "shippingMethodsFetched",
            data: {
              shippingMethods: response.data
            }
          })
        );
      }
      return response;
    },
    getAvailableShippingMethods: async (options = {}) => {
      const response = await sdk.callAction({
        actionName: "cart/getAvailableShippingMethods",
        serverOptions: options.serverOptions
      });
      if (!response.isError) {
        sdk.trigger(
          new import_frontend_sdk.Event({
            eventName: "availableShippingMethodsFetched",
            data: {
              shippingMethods: response.data
            }
          })
        );
      }
      return response;
    },
    setShippingMethod: async (payload, options = {}) => {
      const response = await sdk.callAction({
        actionName: "cart/setShippingMethod",
        payload,
        serverOptions: options.serverOptions
      });
      if (!response.isError) {
        sdk.trigger(
          new import_frontend_sdk.Event({
            eventName: "shippingMethodUpdated",
            data: {
              shippingMethod: response.data.availableShippingMethods?.find(
                (shippingMethod) => shippingMethod.shippingMethodId === payload.shippingMethod.id
              )
            }
          })
        );
      }
      return response;
    },
    redeemDiscountCode: async (payload, options = {}) => {
      const response = await sdk.callAction({
        actionName: "cart/redeemDiscount",
        payload,
        serverOptions: options.serverOptions
      });
      if (!response.isError) {
        sdk.trigger(
          new import_frontend_sdk.Event({
            eventName: "discountCodeRedeemed",
            data: {
              discountCode: typeof response.data !== "string" ? payload.code : response.data,
              cart: typeof response.data !== "string" ? response.data : void 0
            }
          })
        );
      }
      return response;
    },
    removeDiscountCode: async (payload, options = {}) => {
      const response = await sdk.callAction({
        actionName: "cart/removeDiscount",
        payload,
        serverOptions: options.serverOptions
      });
      if (!response.isError) {
        sdk.trigger(
          new import_frontend_sdk.Event({
            eventName: "discountCodeRemoved",
            data: {
              discountCode: payload.discountId,
              cart: response.data
            }
          })
        );
      }
      return response;
    },
    checkout: async (options = {}) => {
      const response = await sdk.callAction({
        actionName: "cart/checkout",
        serverOptions: options.serverOptions
      });
      if (!response.isError) {
        sdk.trigger(
          new import_frontend_sdk.Event({
            eventName: "cartCheckedOut",
            data: {}
          })
        );
      }
      return response;
    },
    getOrderHistory: async (options = {}) => {
      const response = await sdk.callAction({
        actionName: "cart/getOrders",
        serverOptions: options.serverOptions
      });
      if (!response.isError) {
        sdk.trigger(
          new import_frontend_sdk.Event({
            eventName: "orderHistoryFetched",
            data: {
              orders: response.data
            }
          })
        );
      }
      return response;
    }
  };
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  getCartActions
});
//# sourceMappingURL=CartActions.js.map